# cartero

Utilidad para facilitarme la vida en todas aquellas tareas que requieren envío
de correos a través de una interfaz unificada con todas las opciones más
comunes, incluyendo:

- Envío con/sin autenticación y SSL
- Texto plano y HTML
- Reply address
- Unsusbscribe URL
- Archivos adjuntos
- logger configurable (por defecto usa logutils-serpucga)
- Dry run para testeo sin envío efectivo de correos
